==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/kmfwidgets/kmfobjectinfo.h <==
/***************************************************************************
    begin                : Thu Apr 24 2003
    copyright            : (C) 2003 by Christian Hubinger
    email                : chubinger@gmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFOBJECTINFO_H
#define KMFOBJECTINFO_H

#include <qwidget.h>
#include "kmyfirewallobjectinfo.h"

#include <kdemacros.h>

/**
  *@author Christian Hubinger
  */
class NetfilterObject;
class KMFDoc;

class KDE_EXPORT KMFObjectInfo : public KMyFirewallObjectInfo  {
   Q_OBJECT
public: 
	KMFObjectInfo(QWidget *parent=0, const char *name=0, bool modal=false);
	~KMFObjectInfo();

	void loadNetfilterObject( NetfilterObject* );
	void loadKMFDoc( KMFDoc* );

private slots:
	void accept();
	void reject();
	void slotHelp();
	
private: // data
	NetfilterObject* m_netfilter_object;
	KMFDoc* m_doc;
signals:
	void sigDocumentChanged();
	void sigHideMe();
};

#endif

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/kmfwidgets/kmfobjectinfo.h <==
/***************************************************************************
    begin                : Thu Apr 24 2003
    copyright            : (C) 2003 by Christian Hubinger
    email                : chubinger@irrsinnig.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFOBJECTINFO_H
#define KMFOBJECTINFO_H

#include <qwidget.h>
#include "kmyfirewallobjectinfo.h"

#include <kdemacros.h>

/**
  *@author Christian Hubinger
  */
namespace KMF {
class NetfilterObject;
class KMFDoc;

class KDE_EXPORT KMFObjectInfo : public KMyFirewallObjectInfo  {
   Q_OBJECT
public: 
	KMFObjectInfo(QWidget *parent=0, const char *name=0, bool modal=false);
	~KMFObjectInfo();

	void loadNetfilterObject( NetfilterObject* );
	void loadKMFDoc( KMFDoc* );

private slots:
	void accept();
	void reject();
	void slotHelp();
	
private: // data
	NetfilterObject* m_netfilter_object;
	KMFDoc* m_doc;
signals:
	void sigDocumentChanged();
	void sigHideMe();
};
}
#endif
